function _typeof(D){_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(w){return typeof w}:function(w){return w&&"function"===typeof Symbol&&w.constructor===Symbol&&w!==Symbol.prototype?"symbol":typeof w};return _typeof(D)}window.seraph_accel||(window.seraph_accel={});
(function(){function D(a,b){var c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null,d=b.split(3<arguments.length&&void 0!==arguments[3]?arguments[3]:".").reduce(function(h,n){return"object"===_typeof(h)?h[n]:void 0},a);return void 0===d?c:d}function w(a){return"string"===typeof a?a:""}function E(a,b,c){if("string"!==typeof a)return a;if(Array.isArray(b)){for(var d=0;d<b.length;d++)a=E(a,b[d],Array.isArray(c)?c[d]:c);return a}"string"!==typeof b&&(b=""+b);"string"!==typeof c&&(c=""+c);if(a.replaceAll)return a.replaceAll(b,
c);for(d=0;;){d=a.indexOf(b,d);if(-1==d)break;a=a.substr(0,d)+c+a.substr(d+b.length);d+=c.length}return a}function G(a,b){var c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:void 0;if("string"===typeof b)return a.indexOf(b,c);if(!Array.isArray(b))return-1;var d=-1;for(h in b){var h=b[h];var n=a.indexOf(h,c);-1!=n&&(-1==d||d>n)&&(d=n)}return d}function H(a,b){var c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:void 0;if("string"===typeof b)return a.lastIndexOf(b,c);if(!Array.isArray(b))return-1;
var d=-1;for(h in b){var h=b[h];var n=a.lastIndexOf(h,c);-1!=n&&(-1==d||d<n)&&(d=n)}return d}function I(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!0;if(!a||"object"!==_typeof(a))return a;var c=Array===a.constructor?[]:{};for(var d in a)c[d]=b?I(a[d]):a[d];return c}function J(a,b,c){if(void 0===b)return a;if(a&&a.constructor===Array){for(var d in b){var h=b[d];c&&void 0===h||a.push(h)}return a}for(d in b)h=b[d],c&&void 0===h||(a||(a={}),"object"===_typeof(h)&&"object"===_typeof(a[d])?
J(a[d],h,c):a[d]=h);return a}function K(a,b){function c(q,y){var v=d[q];if(!v){var B=b[q];if(!B){v="function"==typeof require&&require;if(!y&&v)return v(q,!0);if(h)return h(q,!0);throw Error('Cannot find module "'+q+'"');}v=d[q]={exports:{}};B[0].call(v.exports,function(r){var z=B[1][r];return c(z?z:r)},v,v.exports,K,a,b,d)}return v.exports}for(var d=2<arguments.length&&void 0!==arguments[2]?arguments[2]:{},h="function"==typeof require&&require,n=0;n<a.length;n++)c(a[n]);return c}seraph_accel.Gen=
{DoesFuncExist:function(a){return"function"===typeof D(window,a)},ParseCmdline:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!0,c=[];if("string"!=typeof a)return c;a=a.trim();for(var d=a.length,h=!1,n="",q=0;q<d;q++)" "!==a.charAt(q)||h?'"'===a.charAt(q)&&b?h=!h:n+=a.charAt(q):(c.push(n),n="");c.push(n);return c},GetFileName:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!1;a=a.split("\\").pop().split("/").pop();b&&(b=a.lastIndexOf("."),-1!=b&&
(a=a.substr(0,b)));return a},GetFileDir:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!1,c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:1;if(!c)return a;if(0<c)for(;;){var d=H(a,["/","\\"],d);if(-1==d||0==d)break;c--;if(!c)break;d--}else for(c*=-1;;){d=G(a,["/","\\"],d);if(-1==d)break;c--;if(!c)break;d++}return-1==d?"":a.substr(0,d+(b?1:0))},GetFileExt:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!1,c=a.lastIndexOf(".");return-1==c?
"":a.substr(c+(b?0:1))},CheckLastSlash:function(a){return"/"==w(a).substr(-1)},SetLastSlash:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!0,c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:"/";if("string"!==typeof a||!a.length)return"";if(a.lastIndexOf(c)==a.length-1){if(!b)return a.substr(0,a.length-1)}else if(b)return a+c;return a},SetFirstSlash:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:!0,c=2<arguments.length&&void 0!==arguments[2]?
arguments[2]:"/";if("string"!==typeof a||!a.length)return"";if(0==a.indexOf(c)){if(!b)return a.substr(1)}else if(b)return c+a;return a},GetStr:w,StrReplaceAll:E,StrReplaceAllWhileChanging:function(a,b,c){if("string"!==typeof a)return a;for(;;){var d=a.length;a=E(a,b,c);if(d==a.length)break}return a},StrIndexOf:G,StrLastIndexOf:H,FilterObjectKeys:function(a){var b=1<arguments.length&&void 0!==arguments[1]?arguments[1]:null,c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null,d={},h;for(h in a)c&&
-1!==c.indexOf(h)||b&&-1===b.indexOf(h)||(d[h]=a[h]);return d},DeepCopy:I,Extend:J,JsonParse:function(a){try{var b=JSON.parse(a)}catch(c){}return b},RegExpFromStr:function(a){var b=a.match(/^([\/~@;%#'])(.*?)\1([gimsuy]*)$/);return b?new RegExp(b[2],b[3].split("").filter(function(c,d,h){return h.indexOf(c)===d}).join("")):new RegExp(a)},GetObjField:D,SetObjField:function(a,b,c){var d=b.split(3<arguments.length&&void 0!==arguments[3]?arguments[3]:".");if(d.length){for(var h=0;h<d.length-1;h++){var n=
d[h];a[n]||(a[n]=h+1<d.length&&"+"==d[h+1]||"string"!==typeof n?[]:{});a=a[n]}n=d[d.length-1];"+"==n?"function"===typeof a.push&&a.push(c):a[n]=c}},GetObjContId:function(a){return E(JSON.stringify(a),'true false { } " : ,'.split(" "),"1      ".split(" "))},AsyncChain:function(){return new Promise(function(a,b){a()})},RunModules:K,EvalInCtx:function(a,b){if(a)return function(){return eval(a)}.call(b)},hr:{SEVERITY_SUCCESS:0,SEVERITY_ERROR:1,FACILITY_INTERNET:12,FACILITY_HTTP:25,S_OK:0,S_FALSE:1,S_FAIL:16389,
S_ABORTED:459975,E_NOTIMPL:2147500033,E_FAIL:2147500037,E_UNSUPPORTED:2147500065,E_INVALIDARG:2147942487,E_INVALID_STATE:2147947423,E_INTERNAL:2147943759,E_DATACORRUPTED:2147943792,E_NOT_FOUND:2147943568,E_ACCESS_DENIED:2147942405,E_ABORTED:2147943623,Make:function(a,b,c){return a<<31|b<<16|c&65535},Code:function(a){return a&65535},Facility:function(a){return a>>16&8191},Succ:function(a){return!(a&2147483648)},Fail:function(a){return!!(a&2147483648)}}};seraph_accel.Plugin={GetErrorDescr:function(a){var b=
1<arguments.length&&void 0!==arguments[1]?arguments[1]:null,c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:!1,d=seraph_accel.Wp.Loc.GetApi(),h=d._x;d=d.sprintf;var n=d("Err_%08X",a),q=c&&seraph_accel.Gen.hr.Succ(a)?d("Err_%08X",seraph_accel.Gen.hr.Make(seraph_accel.Gen.hr.SEVERITY_ERROR,seraph_accel.Gen.hr.Facility(a),a)):null;c=[];b&&(c.push({id:n,ctx:b}),q&&c.push({id:q,ctx:b}));c.push({id:n,ctx:"admin.ErrDescr_Common"});q&&c.push({id:q,ctx:"admin.ErrDescr_Common"});c.push({id:"Def_%08X",
ctx:"admin.ErrDescr_Common"});for(var y in c)if(q=c[y],b=q.id,q=d(h(b,q.ctx,"seraphinite-accelerator"),a),q!=b)return q;return n},GetRootUrl:function(){return this._int.urlRoot},GetAdminApiUrl:function(){return this._int.urlAdminApi},_int:{urlRoot:"",urlAdminApi:""}};seraph_accel.Wp={Loc:{GetApi:function(){var a=null;a=window.wp&&window.wp.i18n?window.wp.i18n:{__:function(b,c){return seraph_accel.Wp.Loc._int.dcnpgettext(c,void 0,b)},_x:function(b,c,d){return seraph_accel.Wp.Loc._int.dcnpgettext(d,
c,b)},_n:function(b,c,d,h){return seraph_accel.Wp.Loc._int.dcnpgettext(h,void 0,b,c,d)},_nx:function(b,c,d,h,n){return seraph_accel.Wp.Loc._int.dcnpgettext(n,h,b,c,d)},sprintf:seraph_accel.Wp.Loc._int.sprintf};a.vsprintf||(a.vsprintf=function(b,c){return a.sprintf.apply(null,[b].concat(c||[]))});return a},SetData:function(a,b){return window.wp&&window.wp.i18n?window.wp.i18n.setLocaleData(a,b):seraph_accel.Wp.Loc._int.setLocaleData(a,b)},GetLang:function(){return seraph_accel.Wp.Loc._int.lang}}};(function(){function a(f){for(var g=
[],k=[],m,p,e;m=f.match(v);){p=m[0];for((e=f.substr(0,m.index).trim())&&g.push(e);e=k.pop();){if(y[p]){if(y[p][0]===e){p=y[p][1]||p;break}}else if(0<=q.indexOf(e)||n[e]<n[p]){k.push(e);break}g.push(e)}y[p]||k.push(p);f=f.substr(m.index+p.length)}(f=f.trim())&&g.push(f);return g.concat(k.reverse())}function b(f){var g=a(f);return function(k){a:{var m=[],p,e;for(p=0;p<g.length;p++){var u=g[p];if(e=B[u])try{var t=e.apply(null,m.splice(-1*e.length))}catch(l){k=l;break a}else t=k.hasOwnProperty(u)?k[u]:
+u;m.push(t)}k=m[0]}return k}}function c(f){var g=b(f);return function(k){return+g({n:k})}}function d(f){var g=f;if(z[g])g=z[g];else{for(var k=g,m,p=[],e=0;k;){if(null!==(m=r.text.exec(k)))p.push(m[0]);else if(null!==(m=r.modulo.exec(k)))p.push("%");else if(null!==(m=r.placeholder.exec(k))){if(m[2]){e|=1;var u=[],t=m[2],l;if(null!==(l=r.key.exec(t)))for(u.push(l[1]);""!==(t=t.substring(l[0].length));)if(null!==(l=r.key_access.exec(t)))u.push(l[1]);else if(null!==(l=r.index_access.exec(t)))u.push(l[1]);
else throw new SyntaxError("[sprintf] failed to parse named argument key");else throw new SyntaxError("[sprintf] failed to parse named argument key");m[2]=u}else e|=2;if(3===e)throw Error("[sprintf] mixing positional and named placeholders is not (yet) supported");p.push({placeholder:m[0],param_no:m[1],keys:m[2],sign:m[3],pad_char:m[4],align:m[5],width:m[6],precision:m[7],type:m[8]})}else throw new SyntaxError("[sprintf] unexpected placeholder");k=k.substring(m[0].length)}g=z[g]=p}k=arguments;m=1;
p=g.length;u="";var x,F;for(t=0;t<p;t++)if("string"===typeof g[t])u+=g[t];else if("object"===_typeof(g[t])){l=g[t];if(l.keys)for(e=k[m],x=0;x<l.keys.length;x++){if(void 0==e)throw Error(d('[sprintf] Cannot access property "%s" of undefined value "%s"',l.keys[x],l.keys[x-1]));e=e[l.keys[x]]}else e=l.param_no?k[l.param_no]:k[m++];r.not_type.test(l.type)&&r.not_primitive.test(l.type)&&e instanceof Function&&(e=e());if(r.numeric_arg.test(l.type)&&"number"!==typeof e&&isNaN(e))throw new TypeError(d("[sprintf] expecting number but found %T",
e));r.number.test(l.type)&&(F=0<=e);switch(l.type){case "b":e=parseInt(e,10).toString(2);break;case "c":e=String.fromCharCode(parseInt(e,10));break;case "d":case "i":e=parseInt(e,10);break;case "j":e=JSON.stringify(e,null,l.width?parseInt(l.width):0);break;case "e":e=l.precision?parseFloat(e).toExponential(l.precision):parseFloat(e).toExponential();break;case "f":e=l.precision?parseFloat(e).toFixed(l.precision):parseFloat(e);break;case "g":e=l.precision?String(Number(e.toPrecision(l.precision))):
parseFloat(e);break;case "o":e=(parseInt(e,10)>>>0).toString(8);break;case "s":e=String(e);e=l.precision?e.substring(0,l.precision):e;break;case "t":e=String(!!e);e=l.precision?e.substring(0,l.precision):e;break;case "T":e=Object.prototype.toString.call(e).slice(8,-1).toLowerCase();e=l.precision?e.substring(0,l.precision):e;break;case "u":e=parseInt(e,10)>>>0;break;case "v":e=e.valueOf();e=l.precision?e.substring(0,l.precision):e;break;case "x":e=(parseInt(e,10)>>>0).toString(16);break;case "X":e=
(parseInt(e,10)>>>0).toString(16).toUpperCase()}if(r.json.test(l.type))u+=e;else{if(!r.number.test(l.type)||F&&!l.sign)var C="";else C=F?"+":"-",e=e.toString().replace(r.sign,"");x=l.pad_char?"0"===l.pad_char?"0":l.pad_char.charAt(1):" ";var A=l.width-(C+e).length;A=l.width?0<A?x.repeat(A):"":"";u+=l.align?C+e+A:"0"===x?C+A+e:A+C+e}}return u}seraph_accel.Wp.Loc._int={data:{},pluralForms:{},options:{contextDelimiter:"\u0004"},lang:"",setLocaleData:function(f,g){f||(f=h);var k=this.data[g];if(k)for(var m in k)f[m]=
k[m];this.data[g]=f},dcnpgettext:function(f,g,k,m,p){this.data[f]||this.setLocaleData(void 0,f);p=void 0===p?0:this.getPluralForm(f,p);var e=k;g&&(e=g+this.options.contextDelimiter+k);return(f=this.data[f][e])&&f[p]?f[p]:0===p?k:m},getPluralForm:function(f,g){var k=this.pluralForms[f];if(!k){k=this.data[f][""];a:{var m;k=(k["Plural-Forms"]||k["plural-forms"]||k.plural_forms).split(";");for(m=0;m<k.length;m++){var p=k[m].trim();if(0===p.indexOf("plural=")){k=p.substr(7);break a}}k=void 0}k=this.pluralForms[f]=
c(k)}return k(g)},sprintf:d};var h={"":{plural_forms:"plural=(n!=1)"}};var n={"(":9,"!":8,"*":7,"/":7,"%":7,"+":6,"-":6,"<":5,"<=":5,">":5,">=":5,"==":4,"!=":4,"&&":3,"||":2,"?":1,"?:":1};var q=["(","?"];var y={")":["("],":":["?","?:"]};var v=/<=|>=|==|!=|&&|\|\||\?:|\(|!|\*|\/|%|\+|-|<|>|\?|\)|:/;var B={"!":function(f){return!f},"*":function(f,g){return f*g},"/":function(f,g){return f/g},"%":function(f,g){return f%g},"+":function(f,g){return f+g},"-":function(f,g){return f-g},"<":function(f,g){return f<
g},"<=":function(f,g){return f<=g},">":function(f,g){return f>g},">=":function(f,g){return f>=g},"==":function(f,g){return f===g},"!=":function(f,g){return f!==g},"&&":function(f,g){return f&&g},"||":function(f,g){return f||g},"?:":function(f,g,k){if(f)throw g;return k}},r={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\x25]+/,modulo:/^\x25{2}/,placeholder:/^\x25(?:([1-9]\d*)\$|\(([^)]+)\))?(\+)?(0|'[^$])?(-)?(\d+)?(?:\.(\d+))?([b-gijostTuvxX])/,
key:/^([a-z_][a-z_\d]*)/i,key_access:/^\.([a-z_][a-z_\d]*)/i,index_access:/^\[(\d+)\]/,sign:/^[+-]/},z=Object.create(null)})()})();
